@@ -55,8 +55,8 @@ class Pose:
                     Vector3(pose.get('rx', 0.0), pose.get('ry', 0.0), pose.get('rz', 0.0)), name=pose.get('name', ''))
 
     @staticmethod
-    def from_list(pose: List) -> 'Pose':
-        return Pose(Vector3(pose[0], pose[1], pose[2]), Vector3(pose[3], pose[4], pose[5]))
+    def from_list(pose: List, name: str = "") -> 'Pose':
+        return Pose(Vector3(pose[0], pose[1], pose[2]), Vector3(pose[3], pose[4], pose[5]), name=name)
 
     @staticmethod
     def pose_trans(p1: 'Pose', p2: 'Pose') -> 'Pose':
